@@ -24,6 +24,7 @@
 
 #include "arrow/status.h"
 
+#include "parquet/util/macros.h"
 #include "parquet/util/visibility.h"
 
 // PARQUET-1085
@@ -58,9 +59,9 @@ namespace parquet {
 
 class PARQUET_EXPORT ParquetException : public std::exception {
  public:
-  static void EofException();
-  static void NYI(const std::string& msg);
-  static void Throw(const std::string& msg);
+  PARQUET_NORETURN static void EofException(const std::string& msg = "");
+  PARQUET_NORETURN static void NYI(const std::string& msg);
+  PARQUET_NORETURN static void Throw(const std::string& msg);
 
   explicit ParquetException(const char* msg);
   explicit ParquetException(const std::string& msg);
